Documentation
¶
Overview ¶
Package clearsign generates and processes OpenPGP, clear-signed data. See RFC 4880, section 7.
Clearsigned messages are cryptographically signed, but the contents of the message are kept in plaintext so that it can be read without special tools.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Chunk ¶
type Chunk struct {
Headers textproto.MIMEHeader // Optional message headers
Plaintext []byte // The original message text
Bytes []byte // The signed message
ArmoredSignature *armor.Chunk // The signature chunk
}
A Chunk represents a clearsigned message. A signature on a Chunk can be checked by passing Bytes into openpgp.CheckDetachedSignature.
Click to show internal directories.
Click to hide internal directories.